/*
 *     SimSelect - Similarity-based Selection for 3D Surfaces
 *
 *     Authors : Emilie GUY, Jean-Marc THIERY and Tamy BOUBEKEUR
 *
 *     Copyright © 2012-2014 Telecom ParisTech - CNRS LTCI - Institut Mines Telecom
 *              All rights reserved
 *
 * This file is part of the SimSelect project
 *
 * SimSelect is free software: you can redistribute it and/or modify
 *
 * it under the terms of the GNU Lesser General Public License as published by
 *
 * the Free Software Foundation, either version 3 of the License, or
 *
 * (at your option) any later version.
 *
 * SimSelect is distributed in the hope that it will be useful,
 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 *
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef QSMARTCOLORPICKER_H
#define QSMARTCOLORPICKER_H

#include <QToolButton>
#include <QColorDialog>

/**
 * @brief The QSmartColorPicker class
 * to pick a color and send it to the app
 */
class QSmartColorPicker : public QToolButton
{
    Q_OBJECT
private:
    QColor bgdColor;
    QWidget * m_parent;
    void changeBackgroundColor( QColor c )
    {
        bgdColor = c;
        setStyleSheet(QString("background-color: rgb(%1, %2, %3); color: rgb(%4, %5, %6)").arg(c.red()).arg(c.green()).arg(c.blue()).arg(c.red()).arg(c.green()).arg(c.blue()));
    }

public:
    QSmartColorPicker (QWidget * p = NULL) : QToolButton (p) , m_parent(p){
        setAutoFillBackground(true);
        connect( this, SIGNAL(clicked()) , this , SLOT(openColorDialog()) );
        setText("  ");
        changeBackgroundColor( QColor( 255,255,255 ) );
    }
    QSmartColorPicker ( QColor c ,QWidget * p = NULL) : QToolButton (p) , m_parent(p){
        setAutoFillBackground(true);
        connect( this, SIGNAL(clicked()) , this , SLOT(openColorDialog()) );
        setText("  ");
        changeBackgroundColor(c);
    }

signals:
    void colorChanged( QColor c );

public slots:
    void openColorDialog(  )
    {
        QColor color = QColorDialog::getColor( bgdColor , m_parent);
        if( color.isValid() )
        {
            changeBackgroundColor(color);
            emit colorChanged(color);
        }
    }
};

#endif // QSMARTCOLORPICKER_H
