/*
 *     SimSelect - Similarity-based Selection for 3D Surfaces
 *
 *     Authors : Emilie GUY, Jean-Marc THIERY and Tamy BOUBEKEUR
 *
 *     Copyright © 2012-2014 Telecom ParisTech - CNRS LTCI - Institut Mines Telecom
 *              All rights reserved
 *
 * This file is part of the SimSelect project
 *
 * SimSelect is free software: you can redistribute it and/or modify
 *
 * it under the terms of the GNU Lesser General Public License as published by
 *
 * the Free Software Foundation, either version 3 of the License, or
 *
 * (at your option) any later version.
 *
 * SimSelect is distributed in the hope that it will be useful,
 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 *
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef SELECTIONDOCK_H
#define SELECTIONDOCK_H

#include <QDockWidget>
#include <QToolBar>
#include "GLViewer.h"

#include <QLabel>
#include <QVBoxLayout>
#include <QSlider>
#include "QSmartColorPicker.h"
#include <QAction>
#include <QFormLayout>

#if (QT_VERSION >= 5)
#include <qcheckbox.h>
#endif

/**
 * @brief The SelectionDock class
 * main dock at the top of the app
 */
class SelectionDock : public QDockWidget
{
    Q_OBJECT
public:
    /**
     * @brief SelectionDock set all the dock
     * @param viewer
     * @param parent
     */
    SelectionDock(/*const QString & title,*/ GLViewer* viewer, QWidget* parent);

private:
    GLViewer* _viewer;  /**< viewer */
    QLabel* _selectionTypeImg;
    bool similarSearchEnable;  /**< if false, the expansion tools are not clickable */
    QAction * expansion;  /**<  expansion button */

    QLabel* sim_threshold ;  /**<  display the number of similar selections */
    QSlider* similarityThreshold; /**<  slider to change the number of similar selections */
    QLabel* similarityValueLabel;

    QToolBar* controlStroke;   /**< toolbar to set basic controls on the selection (erase, delete...) */
    QAction * drawStroke; /**< to refine the selection */
    QAction * addSelections; /**< to validate the current selection */
    QAction * eraseStroke; /**< to erase a part of the current selection */
    QAction * deleteSelection; /**< to delete one selection */
    QAction * deleteAll; /**< to delete all selections */
    QAction * reverseSelection; /**< to reverse the current selection */
    QAction * select; /**< to start a selection */

signals:
public slots:
    /**
     * @brief activateStrokeMode
     * @param b if true the user is selecting and the menu becomes clickable
     */
    void activateStrokeMode(bool b);

    /**
     * @brief setSelectionType set the selection type (comp, part, patch)
     * @param action
     */
    void setSelectionType(QAction* action);

    /**
     * @brief resetStrokeToDraw the selection toolbar becomes checkable
     */
    void resetStrokeToDraw();

    /**
     * @brief changeSimilarityValueLabel to update the display
     * of the number of similar selections
     * @param v similar selections
     */
    void changeSimilarityValueLabel(int v);

    /**
     * @brief setSelectionManagementToZero0
     * set the draw stroke mode of the viewer to true or false depending on the QAction value
     */
    void setSelectionManagementToZero0();

    /**
     * @brief setSelectionManagementToZero1
     * set the eraser mode of the viewer to true or false depending on the QAction value
     */
    void setSelectionManagementToZero1();

    /**
     * @brief setSelectionManagementToZero2
     * set the delete selection mode of the viewer to true or false depending on the QAction value
     */
    void setSelectionManagementToZero2();

    /**
     * @brief setSelectionManagementToZero2
     * set the delete all mode of the viewer to true or false depending on the QAction value
     */
    void setSelectionManagementToZero3();
};

#endif // SELECTIONDOCK_H
